@@ -534,8 +534,8 @@ static int ht_expand_if_needed(struct hashtable *t)
 	 * if the table is half-full redobule its size. */
 	if (t->size == 0)
 		return ht_expand(t, HT_INITIAL_SIZE);
-	if (t->size <= (t->used << 1))
-		return ht_expand(t, t->size << 1);
+	if (t->size <= t->used*2)
+		return ht_expand(t, t->size * 2);
 	return HT_OK;
 }
 
